@@ -4,11 +4,14 @@ namespace Icinga\Module\Businessprocess\Clicommands;
 
 use Exception;
 use Icinga\Application\Logger;
+use Icinga\Application\Modules\Module;
 use Icinga\Cli\Command;
 use Icinga\Module\Businessprocess\BpConfig;
 use Icinga\Module\Businessprocess\BpNode;
 use Icinga\Module\Businessprocess\HostNode;
 use Icinga\Module\Businessprocess\Node;
+use Icinga\Module\Businessprocess\ProvidedHook\Icingadb\IcingadbSupport;
+use Icinga\Module\Businessprocess\State\IcingaDbState;
 use Icinga\Module\Businessprocess\State\MonitoringState;
 use Icinga\Module\Businessprocess\Storage\LegacyStorage;
 
@@ -101,6 +104,12 @@ class ProcessCommand extends Command
      */
     public function checkAction()
     {
+        $nodeName = $this->params->shift();
+        if (! $nodeName) {
+            Logger::error('A process name is required');
+            exit(1);
+        }
+
         try {
             $name = $this->params->get('config');
             if ($name === null) {
@@ -125,15 +134,22 @@ class ProcessCommand extends Command
 
         /** @var BpNode $node */
         try {
-            $node = $bp->getNode($this->params->shift());
-            MonitoringState::apply($bp);
+            $node = $bp->getNode($nodeName);
+            if (Module::exists('icingadb')
+                && (! $bp->hasBackendName() && IcingadbSupport::useIcingaDbAsBackend())
+            ) {
+                IcingaDbState::apply($bp);
+            } else {
+                MonitoringState::apply($bp);
+            }
+
             if ($bp->hasErrors()) {
                 Logger::error("Checking Business Process '%s' failed: %s\n", $name, $bp->getErrors());
 
                 exit(3);
             }
         } catch (Exception $err) {
-            Logger::error("Checking Business Process '%s' failed: %s", $name, $err->getMessage());
+            Logger::error("Checking Business Process '%s' failed: %s", $name, $err);
 
             exit(3);
         }
@@ -167,21 +183,22 @@ class ProcessCommand extends Command
         }
     }
 
-    protected function renderProblemTree($tree, $useColors = false, $depth = 0)
+    protected function renderProblemTree($tree, $useColors = false, $depth = 0, BpNode $parent = null)
     {
         $output = '';
 
         foreach ($tree as $name => $subtree) {
             /** @var Node $node */
             $node = $subtree['node'];
+            $state = $parent !== null ? $parent->getChildState($node) : $node->getState();
 
             if ($node instanceof HostNode) {
-                $colors = $this->hostColors[$node->getState()];
+                $colors = $this->hostColors[$state];
             } else {
-                $colors = $this->serviceColors[$node->getState()];
+                $colors = $this->serviceColors[$state];
             }
 
-            $state = sprintf('[%s]', $node->getStateName());
+            $state = sprintf('[%s]', $node->getStateName($state));
             if ($useColors) {
                 $state = $this->screen->colorize($state, $colors[0], $colors[1]);
             }
@@ -193,7 +210,10 @@ class ProcessCommand extends Command
                 $state,
                 $node->getAlias()
             );
-            $output .= $this->renderProblemTree($subtree['children'], $useColors, $depth + 1);
+
+            if ($node instanceof BpNode) {
+                $output .= $this->renderProblemTree($subtree['children'], $useColors, $depth + 1, $node);
+            }
         }
 
         return $output;
