@@ -2,9 +2,12 @@
 
 namespace Icinga\Module\Businessprocess\Controllers;
 
+use Icinga\Application\Modules\Module;
+use Icinga\Module\Businessprocess\ProvidedHook\Icingadb\IcingadbSupport;
 use Icinga\Module\Businessprocess\Renderer\Breadcrumb;
 use Icinga\Module\Businessprocess\Renderer\TileRenderer;
 use Icinga\Module\Businessprocess\Simulation;
+use Icinga\Module\Businessprocess\State\IcingaDbState;
 use Icinga\Module\Businessprocess\State\MonitoringState;
 use Icinga\Module\Businessprocess\Web\Controller;
 use Icinga\Module\Businessprocess\Web\Url;
@@ -82,7 +85,13 @@ class NodeController extends Controller
                 continue;
             }
 
-            MonitoringState::apply($config);
+            if (Module::exists('icingadb') &&
+                (! $config->getBackendName() && IcingadbSupport::useIcingaDbAsBackend())
+            ) {
+                IcingaDbState::apply($config);
+            } else {
+                MonitoringState::apply($config);
+            }
             $config->applySimulation($simulation);
 
             foreach ($parents as $parentAndPath) {
