@@ -2,15 +2,18 @@
 
 namespace Icinga\Module\Businessprocess\Controllers;
 
+use Icinga\Application\Modules\Module;
 use Icinga\Date\DateFormatter;
 use Icinga\Module\Businessprocess\BpConfig;
 use Icinga\Module\Businessprocess\BpNode;
 use Icinga\Module\Businessprocess\Node;
+use Icinga\Module\Businessprocess\ProvidedHook\Icingadb\IcingadbSupport;
 use Icinga\Module\Businessprocess\Renderer\Breadcrumb;
 use Icinga\Module\Businessprocess\Renderer\Renderer;
 use Icinga\Module\Businessprocess\Renderer\TileRenderer;
 use Icinga\Module\Businessprocess\Renderer\TreeRenderer;
 use Icinga\Module\Businessprocess\Simulation;
+use Icinga\Module\Businessprocess\State\IcingaDbState;
 use Icinga\Module\Businessprocess\State\MonitoringState;
 use Icinga\Module\Businessprocess\Storage\ConfigDiff;
 use Icinga\Module\Businessprocess\Storage\LegacyConfigRenderer;
@@ -81,7 +84,14 @@ class ProcessController extends Controller
         $bp = $this->loadModifiedBpConfig();
         $node = $this->getNode($bp);
 
-        MonitoringState::apply($bp);
+        if (Module::exists('icingadb') &&
+            (! $bp->hasBackendName() && IcingadbSupport::useIcingaDbAsBackend())
+        ) {
+            IcingaDbState::apply($bp);
+        } else {
+            MonitoringState::apply($bp);
+        }
+
         $this->handleSimulations($bp);
 
         $this->setTitle($this->translate('Business Process "%s"'), $bp->getTitle());
@@ -562,7 +572,7 @@ class ProcessController extends Controller
             case 'csv':
                 $csv = fopen('php://temp', 'w');
 
-                fputcsv($csv, ['Path', 'Name', 'State', 'Since']);
+                fputcsv($csv, ['Path', 'Name', 'State', 'Since', 'In_Downtime']);
 
                 foreach ($node !== null ? $node->toArray(null, true) : $bp->toArray(true) as $node) {
                     $data = [$node['path'], $node['name']];
@@ -574,6 +584,10 @@ class ProcessController extends Controller
                     if (isset($node['since'])) {
                         $data[] = DateFormatter::formatDateTime($node['since']);
                     }
+                    
+                    if (isset($node['in_downtime'])) {
+                        $data[] = $node['in_downtime'];
+                    }
 
                     fputcsv($csv, $data);
                 }
