@@ -4,20 +4,21 @@ namespace Icinga\Module\Businessprocess\Forms;
 
 use Icinga\Module\Businessprocess\BpNode;
 use Icinga\Module\Businessprocess\BpConfig;
+use Icinga\Module\Businessprocess\Common\EnumList;
 use Icinga\Module\Businessprocess\ImportedNode;
 use Icinga\Module\Businessprocess\Modification\ProcessChanges;
-use Icinga\Module\Businessprocess\MonitoringRestrictions;
 use Icinga\Module\Businessprocess\Storage\Storage;
 use Icinga\Module\Businessprocess\Web\Form\QuickForm;
 use Icinga\Module\Businessprocess\Web\Form\Validator\NoDuplicateChildrenValidator;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Web\Session\SessionNamespace;
+use ipl\Sql\Connection as IcingaDbConnection;
 
 class AddNodeForm extends QuickForm
 {
-    use MonitoringRestrictions;
+    use EnumList;
 
-    /** @var MonitoringBackend */
+    /** @var MonitoringBackend|IcingaDbConnection*/
     protected $backend;
 
     /** @var Storage */
@@ -65,6 +66,12 @@ class AddNodeForm extends QuickForm
             case 'new-process':
                 $this->addNewProcess();
                 break;
+            case 'hosts_from_filter':
+                $this->selectHostsFromFilter();
+                break;
+            case 'services_from_filter':
+                $this->selectServicesFromFilter();
+                break;
             case null:
                 $this->setSubmitLabel($this->translate('Next'));
                 return;
@@ -110,6 +117,7 @@ class AddNodeForm extends QuickForm
                 '&' => $this->translate('AND'),
                 '|' => $this->translate('OR'),
                 '!' => $this->translate('NOT'),
+                '%' => $this->translate('DEGRADED'),
                 '1' => $this->translate('MIN 1'),
                 '2' => $this->translate('MIN 2'),
                 '3' => $this->translate('MIN 3'),
@@ -157,6 +165,8 @@ class AddNodeForm extends QuickForm
         if ($this->hasParentNode()) {
             $types['host'] = $this->translate('Host');
             $types['service'] = $this->translate('Service');
+            $types['hosts_from_filter'] = $this->translate('Hosts from filter');
+            $types['services_from_filter'] = $this->translate('Services from filter');
         } elseif (! $this->hasProcesses()) {
             $this->addElement('hidden', 'node_type', array(
                 'ignore'     => true,
@@ -200,6 +210,11 @@ class AddNodeForm extends QuickForm
             ),
             'validators'    => [[new NoDuplicateChildrenValidator($this, $this->bp, $this->parent), true]]
         ]);
+
+        $this->addHostOverrideCheckbox();
+        if ($this->getSentValue('host_override') === '1') {
+            $this->addHostOverrideElement();
+        }
     }
 
     protected function selectService()
@@ -207,6 +222,11 @@ class AddNodeForm extends QuickForm
         $this->addHostElement();
         if ($host = $this->getSentValue('host')) {
             $this->addServicesElement($host);
+            $this->addServiceOverrideCheckbox();
+
+            if ($this->getSentValue('service_override') === '1') {
+                $this->addServiceOverrideElement();
+            }
         } else {
             $this->setSubmitLabel($this->translate('Next'));
         }
@@ -238,6 +258,53 @@ class AddNodeForm extends QuickForm
         ]);
     }
 
+    protected function addFilteredHostsElement($filter)
+    {
+        $this->addElement('submit', 'refresh', [
+            'label'        => $this->translate('Refresh'),
+            'class'        => 'refresh-filter'
+        ]);
+        $this->addElement('multiselect', 'children', [
+            'label'        => $this->translate('Hosts'),
+            'required'     => true,
+            'size'         => 8,
+            'style'        => 'width: 25em',
+            'multiOptions' => $this->enumHostListByFilter($filter),
+            'description'  => $this->translate(
+                'Hosts that should be part of this business process node'
+            ),
+            'validators'    => [[new NoDuplicateChildrenValidator($this, $this->bp, $this->parent), true]]
+        ]);
+    }
+
+    protected function addFilteredServicesElement($filter)
+    {
+        $this->addElement('submit', 'refresh', [
+            'label'        => $this->translate('Refresh'),
+            'class'        => 'refresh-filter'
+        ]);
+        $this->addElement('multiselect', 'children', [
+            'label'        => $this->translate('Services'),
+            'required'     => true,
+            'size'         => 8,
+            'style'        => 'width: 25em',
+            'multiOptions' => $this->enumServiceListByFilter($filter),
+            'description'  => $this->translate(
+                'Services that should be part of this business process node'
+            ),
+            'validators'    => [[new NoDuplicateChildrenValidator($this, $this->bp, $this->parent), true]]
+        ]);
+    }
+
+    protected function addFilterElement()
+    {
+        $this->addElement('text', 'filter', array(
+            'label'        => $this->translate('Filter'),
+            'required'     => true,
+            'ignore'       => true
+        ));
+    }
+
     protected function addFileElement()
     {
         $this->addElement('select', 'file', [
@@ -253,6 +320,64 @@ class AddNodeForm extends QuickForm
         ]);
     }
 
+    protected function addHostOverrideCheckbox()
+    {
+        $this->addElement('checkbox', 'host_override', [
+            'ignore'        => true,
+            'class'         => 'autosubmit',
+            'label'         => $this->translate('Override Host State'),
+            'description'   => $this->translate('Enable host state overrides')
+        ]);
+    }
+
+    protected function addHostOverrideElement()
+    {
+        $this->addElement('stateOverrides', 'stateOverrides', [
+            'required'  => true,
+            'label'     => $this->translate('State Overrides'),
+            'states'    => $this->enumHostStateList()
+        ]);
+    }
+
+    protected function addServiceOverrideCheckbox()
+    {
+        $this->addElement('checkbox', 'service_override', [
+            'ignore'        => true,
+            'class'         => 'autosubmit',
+            'label'         => $this->translate('Override Service State'),
+            'description'   => $this->translate('Enable service state overrides')
+        ]);
+    }
+
+    protected function addServiceOverrideElement()
+    {
+        $this->addElement('stateOverrides', 'stateOverrides', [
+            'required'  => true,
+            'label'     => $this->translate('State Overrides'),
+            'states'    => $this->enumServiceStateList()
+        ]);
+    }
+
+    protected function selectHostsFromFilter()
+    {
+        $this->addFilterElement();
+        if ($filter = $this->getSentValue('filter')) {
+            $this->addFilteredHostsElement($filter);
+        } else {
+            $this->setSubmitLabel($this->translate('Next'));
+        }
+    }
+
+    protected function selectServicesFromFilter()
+    {
+        $this->addFilterElement();
+        if ($filter = $this->getSentValue('filter')) {
+            $this->addFilteredServicesElement($filter);
+        } else {
+            $this->setSubmitLabel($this->translate('Next'));
+        }
+    }
+
     protected function selectProcess()
     {
         if ($this->hasParentNode()) {
@@ -277,10 +402,10 @@ class AddNodeForm extends QuickForm
     }
 
     /**
-     * @param MonitoringBackend $backend
+     * @param MonitoringBackend|IcingaDbConnection $backend
      * @return $this
      */
-    public function setBackend(MonitoringBackend $backend)
+    public function setBackend($backend)
     {
         $this->backend = $backend;
         return $this;
@@ -335,62 +460,6 @@ class AddNodeForm extends QuickForm
         return $this;
     }
 
-    protected function enumHostForServiceList()
-    {
-        $names = $this->backend
-            ->select()
-            ->from('hostStatus', ['hostname' => 'host_name'])
-            ->applyFilter($this->getRestriction('monitoring/filter/objects'))
-            ->order('host_name')
-            ->getQuery()
-            ->fetchColumn();
-
-        // fetchPairs doesn't seem to work when using the same column with
-        // different aliases twice
-
-        return array_combine((array) $names, (array) $names);
-    }
-
-    protected function enumHostList()
-    {
-        $names = $this->backend
-            ->select()
-            ->from('hostStatus', ['hostname' => 'host_name'])
-            ->applyFilter($this->getRestriction('monitoring/filter/objects'))
-            ->order('host_name')
-            ->getQuery()
-            ->fetchColumn();
-
-        // fetchPairs doesn't seem to work when using the same column with
-        // different aliases twice
-        $res = array();
-        $suffix = ';Hoststatus';
-        foreach ($names as $name) {
-            $res[$name . $suffix] = $name;
-        }
-
-        return $res;
-    }
-
-    protected function enumServiceList($host)
-    {
-        $names = $this->backend
-            ->select()
-            ->from('serviceStatus', ['service' => 'service_description'])
-            ->where('host_name', $host)
-            ->applyFilter($this->getRestriction('monitoring/filter/objects'))
-            ->order('service_description')
-            ->getQuery()
-            ->fetchColumn();
-
-        $services = array();
-        foreach ($names as $name) {
-            $services[$host . ';' . $name] = $name;
-        }
-
-        return $services;
-    }
-
     protected function hasProcesses()
     {
         return count($this->enumProcesses()) > 0;
@@ -466,7 +535,22 @@ class AddNodeForm extends QuickForm
         switch ($this->getValue('node_type')) {
             case 'host':
             case 'service':
+                $stateOverrides = $this->getValue('stateOverrides');
+                if (! empty($stateOverrides)) {
+                    $childOverrides = [];
+                    foreach ($this->getValue('children') as $service) {
+                        $childOverrides[$service] = $stateOverrides;
+                    }
+
+                    $changes->modifyNode($this->parent, [
+                        'stateOverrides' => array_merge($this->parent->getStateOverrides(), $childOverrides)
+                    ]);
+                }
+
+                // Fallthrough
             case 'process':
+            case 'hosts_from_filter':
+            case 'services_from_filter':
                 if ($this->hasParentNode()) {
                     $changes->addChildrenToNode($this->getValue('children'), $this->parent);
                 } else {
