@@ -51,16 +51,18 @@ class BpConfigForm extends BpConfigBaseForm
             'rows' => 4,
         ));
 
-        $this->addElement('select', 'Backend', array(
-            'label'       => $this->translate('Backend'),
-            'description' => $this->translate(
-                'Icinga Web Monitoring Backend where current object states for'
-                . ' this process should be retrieved from'
-            ),
-            'multiOptions' => array(
-                null => $this->translate('Use the configured default backend'),
-            ) + $this->listAvailableBackends()
-        ));
+        if (! empty($this->listAvailableBackends())) {
+            $this->addElement('select', 'Backend', array(
+                'label'       => $this->translate('Backend'),
+                'description' => $this->translate(
+                    'Icinga Web Monitoring Backend where current object states for'
+                    . ' this process should be retrieved from'
+                ),
+                'multiOptions' => array(
+                        null => $this->translate('Use the configured default backend'),
+                    ) + $this->listAvailableBackends()
+            ));
+        }
 
         $this->addElement('select', 'Statetype', array(
             'label'       => $this->translate('State Type'),
@@ -86,6 +88,27 @@ class BpConfigForm extends BpConfigBaseForm
             )
         ));
 
+        $this->addElement('text', 'AllowedUsers', array(
+            'label'       => $this->translate('Allowed Users'),
+            'description' => $this->translate(
+                'Allowed Users (comma-separated)'
+            ),
+        ));
+
+        $this->addElement('text', 'AllowedGroups', array(
+            'label'       => $this->translate('Allowed Groups'),
+            'description' => $this->translate(
+                'Allowed Groups (comma-separated)'
+            ),
+        ));
+
+        $this->addElement('text', 'AllowedRoles', array(
+            'label'       => $this->translate('Allowed Roles'),
+            'description' => $this->translate(
+                'Allowed Roles (comma-separated)'
+            ),
+        ));
+
         if ($this->config === null) {
             $this->setSubmitLabel(
                 $this->translate('Add')
@@ -167,9 +190,11 @@ class BpConfigForm extends BpConfigBaseForm
         }
         $meta = $config->getMetadata();
         foreach ($this->getValues() as $key => $value) {
-            if ($value === null || $value === '') {
+            if (! in_array($key, ['Title', 'Description', 'Backend'], true)
+                && ($value === null || $value === '')) {
                 continue;
             }
+
             if ($meta->hasKey($key)) {
                 $meta->set($key, $value);
             }
