@@ -9,10 +9,11 @@ use Icinga\Module\Businessprocess\Node;
 use Icinga\Module\Businessprocess\Web\Form\QuickForm;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Web\Session\SessionNamespace;
+use ipl\Sql\Connection as IcingaDbConnection;
 
 class DeleteNodeForm extends QuickForm
 {
-    /** @var MonitoringBackend */
+    /** @var MonitoringBackend|IcingaDbConnection */
     protected $backend;
 
     /** @var BpConfig */
@@ -79,10 +80,10 @@ class DeleteNodeForm extends QuickForm
     }
 
     /**
-     * @param MonitoringBackend $backend
+     * @param MonitoringBackend|IcingaDbConnection $backend
      * @return $this
      */
-    public function setBackend(MonitoringBackend $backend)
+    public function setBackend($backend)
     {
         $this->backend = $backend;
         return $this;
