@@ -9,10 +9,11 @@ use Icinga\Module\Businessprocess\Web\Form\QuickForm;
 use Icinga\Module\Monitoring\Backend\MonitoringBackend;
 use Icinga\Web\Notification;
 use Icinga\Web\Session\SessionNamespace;
+use ipl\Sql\Connection as IcingaDbConnection;
 
 class ProcessForm extends QuickForm
 {
-    /** @var MonitoringBackend */
+    /** @var MonitoringBackend|IcingaDbConnection */
     protected $backend;
 
     /** @var BpConfig */
@@ -61,6 +62,7 @@ class ProcessForm extends QuickForm
                 '&' => $this->translate('AND'),
                 '|' => $this->translate('OR'),
                 '!' => $this->translate('NOT'),
+                '%' => $this->translate('DEGRADED'),
                 '1' => $this->translate('MIN 1'),
                 '2' => $this->translate('MIN 2'),
                 '3' => $this->translate('MIN 3'),
@@ -110,10 +112,10 @@ class ProcessForm extends QuickForm
     }
 
     /**
-     * @param MonitoringBackend $backend
+     * @param MonitoringBackend|IcingaDbConnection $backend
      * @return $this
      */
-    public function setBackend(MonitoringBackend $backend)
+    public function setBackend($backend)
     {
         $this->backend = $backend;
         return $this;
