@@ -11,6 +11,7 @@ class BpNode extends Node
     const OP_AND = '&';
     const OP_OR  = '|';
     const OP_NOT  = '!';
+    const OP_DEGRADED  = '%';
 
     protected $operator = '&';
     protected $url;
@@ -26,17 +27,18 @@ class BpNode extends Node
     protected $missing = null;
     protected $empty = null;
     protected $missingChildren;
+    protected $stateOverrides = [];
 
     protected static $emptyStateSummary = array(
-        'OK'          => 0,
-        'WARNING'     => 0,
-        'CRITICAL'    => 0,
-        'UNKNOWN'     => 0,
-        'PENDING'     => 0,
-        'UP'          => 0,
-        'DOWN'        => 0,
-        'UNREACHABLE' => 0,
-        'MISSING'     => 0,
+        'CRITICAL'            => 0,
+        'CRITICAL-HANDLED'    => 0,
+        'WARNING'             => 0,
+        'WARNING-HANDLED'     => 0,
+        'UNKNOWN'             => 0,
+        'UNKNOWN-HANDLED'     => 0,
+        'OK'                  => 0,
+        'PENDING'             => 0,
+        'MISSING'             => 0,
     );
 
     protected static $sortStateInversionMap = array(
@@ -63,16 +65,27 @@ class BpNode extends Node
             $this->counters = self::$emptyStateSummary;
 
             foreach ($this->getChildren() as $child) {
-                if ($child instanceof BpNode) {
-                    $counters = $child->getStateSummary();
-                    foreach ($counters as $k => $v) {
-                        $this->counters[$k] += $v;
-                    }
-                } elseif ($child->isMissing()) {
+                if ($child->isMissing()) {
                     $this->counters['MISSING']++;
                 } else {
-                    $state = $child->getStateName();
-                    $this->counters[$state]++;
+                    $state = $child->getStateName($this->getChildState($child));
+                    if ($child->isHandled() && ($state !== 'UP' && $state !== 'OK')) {
+                        $state = $state . '-HANDLED';
+                    }
+
+                    if ($state === 'DOWN') {
+                        $this->counters['CRITICAL']++;
+                    } elseif ($state === 'DOWN-HANDLED') {
+                        $this->counters['CRITICAL-HANDLED']++;
+                    } elseif ($state === 'UNREACHABLE') {
+                        $this->counters['UNKNOWN']++;
+                    } elseif ($state === 'UNREACHABLE-HANDLED') {
+                        $this->counters['UNKNOWN-HANDLED']++;
+                    } elseif ($state === 'UP') {
+                        $this->counters['OK']++;
+                    } else {
+                        $this->counters[$state]++;
+                    }
                 }
             }
         }
@@ -127,9 +140,13 @@ class BpNode extends Node
         $problems = array();
 
         foreach ($this->getChildren() as $child) {
-            if ($child->isProblem()
-                || ($child instanceof BpNode && $child->hasProblems())
-            ) {
+            if (isset($this->stateOverrides[$child->getName()])) {
+                $problem = $this->getChildState($child) > 0;
+            } else {
+                $problem = $child->isProblem() || ($child instanceof BpNode && $child->hasProblems());
+            }
+
+            if ($problem) {
                 $problems[] = $child;
             }
         }
@@ -187,7 +204,8 @@ class BpNode extends Node
 
         if ($nodeState !== 0) {
             foreach ($this->getChildren() as $child) {
-                $childState = $rootCause ? $child->getSortingState() : $child->getState();
+                $childState = $this->getChildState($child);
+                $childState = $rootCause ? $child->getSortingState($childState) : $childState;
                 if (($rootCause ? $this->getSortingState() : $nodeState) === $childState) {
                     $name = $child->getName();
                     $tree[$name] = [
@@ -283,6 +301,7 @@ class BpNode extends Node
             case self::OP_AND:
             case self::OP_OR:
             case self::OP_NOT:
+            case self::OP_DEGRADED:
                 return;
             default:
                 if (is_numeric($operator)) {
@@ -327,6 +346,31 @@ class BpNode extends Node
         return $this->info_command;
     }
 
+    public function setStateOverrides(array $overrides, $name = null)
+    {
+        if ($name === null) {
+            $this->stateOverrides = $overrides;
+        } else {
+            $this->stateOverrides[$name] = $overrides;
+        }
+
+        return $this;
+    }
+
+    public function getStateOverrides($name = null)
+    {
+        $overrides = null;
+        if ($name !== null) {
+            if (isset($this->stateOverrides[$name])) {
+                $overrides = $this->stateOverrides[$name];
+            }
+        } else {
+            $overrides = $this->stateOverrides;
+        }
+
+        return $overrides;
+    }
+
     public function getAlias()
     {
         return $this->alias ? preg_replace('~_~', ' ', $this->alias) : $this->name;
@@ -354,6 +398,27 @@ class BpNode extends Node
         return $this->state;
     }
 
+    /**
+     * Get the given child's state, possibly adjusted by override rules
+     *
+     * @param Node|string $child
+     * @return int
+     */
+    public function getChildState($child)
+    {
+        if (! $child instanceof Node) {
+            $child = $this->getChildByName($child);
+        }
+
+        $childName = $child->getName();
+        $childState = $child->getState();
+        if (! isset($this->stateOverrides[$childName][$childState])) {
+            return $childState;
+        }
+
+        return $this->stateOverrides[$childName][$childState];
+    }
+
     public function getHtmlId()
     {
         return 'businessprocess-' . preg_replace('/[\r\n\t\s]/', '_', $this->getName());
@@ -391,7 +456,7 @@ class BpNode extends Node
 
                 $child->setMissing();
             }
-            $sort_states[] = $child->getSortingState();
+            $sort_states[] = $child->getSortingState($this->getChildState($child));
             $lastStateChange = max($lastStateChange, $child->getLastStateChange());
             $bp->endLoopDetection($this->name);
         }
@@ -408,6 +473,15 @@ class BpNode extends Node
             case self::OP_OR:
                 $sort_state = min($sort_states);
                 break;
+            case self::OP_DEGRADED:
+                $maxState = max($sort_states);
+                $flags = $maxState & 0xf;
+
+                $maxIcingaState = $this->sortStateTostate($maxState);
+                $warningState = ($this->stateToSortState(self::ICINGA_WARNING) << self::SHIFT_FLAGS) + $flags;
+
+                $sort_state = ($maxIcingaState === self::ICINGA_CRITICAL) ? $warningState : $maxState;
+                break;
             default:
                 // MIN:
                 $sort_state = 3 << self::SHIFT_FLAGS;
@@ -572,6 +646,9 @@ class BpNode extends Node
             case self::OP_NOT:
                 return 'NOT';
                 break;
+            case self::OP_DEGRADED:
+                return 'DEG';
+                break;
             default:
                 // MIN
                 $this->assertNumericOperator();
