@@ -249,9 +249,11 @@ abstract class Node
         return $this->state;
     }
 
-    public function getSortingState()
+    public function getSortingState($state = null)
     {
-        $state = $this->getState();
+        if ($state === null) {
+            $state = $this->getState();
+        }
 
         if (self::$ackIsOk && $this->isAcknowledged()) {
             $state = self::ICINGA_OK;
@@ -509,7 +511,8 @@ abstract class Node
         $data = [
             'name'  => $this->getAlias(),
             'state' => $this->getStateName(),
-            'since' => $this->getLastStateChange()
+            'since' => $this->getLastStateChange(),
+            'in_downtime' => $this->isInDowntime() ? true : false
         ];
 
         if ($parent !== null) {
