@@ -12,6 +12,7 @@ use Icinga\Module\Businessprocess\Web\Url;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
 use ipl\Html\HtmlDocument;
+use ipl\Web\Widget\StateBadge;
 
 abstract class Renderer extends HtmlDocument
 {
@@ -135,34 +136,31 @@ abstract class Renderer extends HtmlDocument
      * @param $summary
      * @return BaseHtmlElement
      */
-    public function renderStateBadges($summary)
+    public function renderStateBadges($summary, $totalChildren)
     {
         $elements = [];
 
-        foreach ($summary as $state => $cnt) {
-            if ($cnt === 0
-                || $state === 'OK'
-                || $state === 'UP'
-            ) {
-                continue;
-            }
+        $itemCount = Html::tag(
+            'span',
+            [
+                'class' => [
+                    'item-count',
+                ]
+            ],
+            sprintf(mtp('businessprocess', '%u Child', '%u Children', $totalChildren), $totalChildren)
+        );
 
-            $elements[] = Html::tag(
-                'span',
-                [
-                    'class' => [
-                        'badge',
-                        'badge-' . strtolower($state)
-                    ],
-                    // TODO: We should translate this in this module
-                    'title' => mt('monitoring', $state)
-                ],
-                $cnt
-            );
-        }
+        $elements[] = array_filter([
+            $this->createBadgeGroup($summary, 'CRITICAL'),
+            $this->createBadgeGroup($summary, 'UNKNOWN'),
+            $this->createBadgeGroup($summary, 'WARNING'),
+            $this->createBadge($summary, 'MISSING'),
+            $this->createBadge($summary, 'PENDING')
+        ]);
 
         if (!empty($elements)) {
-            $container = Html::tag('div', ['class' => 'badges']);
+            $container = Html::tag('ul', ['class' => 'state-badges']);
+            $container->add($itemCount);
             foreach ($elements as $element) {
                 $container->add($element);
             }
@@ -172,6 +170,33 @@ abstract class Renderer extends HtmlDocument
         return null;
     }
 
+    protected function createBadge($summary, $state)
+    {
+        if ($summary[$state] !== 0) {
+            return Html::tag('li', new StateBadge($summary[$state], strtolower($state)));
+        }
+
+        return null;
+    }
+
+    protected function createBadgeGroup($summary, $state)
+    {
+        $content = [];
+        if ($summary[$state] !== 0) {
+            $content[] = Html::tag('li', new StateBadge($summary[$state], strtolower($state)));
+        }
+
+        if ($summary[$state . '-HANDLED'] !== 0) {
+            $content[] = Html::tag('li', new StateBadge($summary[$state . '-HANDLED'], strtolower($state), true));
+        }
+
+        if (empty($content)) {
+            return null;
+        }
+
+        return Html::tag('li', Html::tag('ul', $content));
+    }
+
     public function getNodeClasses(Node $node)
     {
         if ($node->isMissing()) {
@@ -180,9 +205,9 @@ abstract class Renderer extends HtmlDocument
             if ($node->isEmpty() && ! $node instanceof MonitoredNode) {
                 $classes = array('empty');
             } else {
-                $classes = array(
-                    strtolower($node->getStateName())
-                );
+                $classes = [strtolower($node->getStateName(
+                    $this->parent !== null ? $this->parent->getChildState($node) : null
+                ))];
             }
             if ($node->hasMissingChildren()) {
                 $classes[] = 'missing-children';
