@@ -7,10 +7,11 @@ use Icinga\Module\Businessprocess\BpConfig;
 use Icinga\Module\Businessprocess\BpNode;
 use Icinga\Module\Businessprocess\ImportedNode;
 use Icinga\Module\Businessprocess\Node;
-use Icinga\Module\Businessprocess\Web\Component\StateBall;
 use Icinga\Module\Businessprocess\Web\Form\CsrfToken;
+use Icinga\Module\Icingadb\Model\State;
 use ipl\Html\BaseHtmlElement;
 use ipl\Html\Html;
+use ipl\Web\Widget\StateBall;
 
 class TreeRenderer extends Renderer
 {
@@ -79,7 +80,7 @@ class TreeRenderer extends Renderer
             if ($node instanceof BpNode) {
                 $html[] = $this->renderNode($bp, $node);
             } else {
-                $html[] = $this->renderChild($bp, $node);
+                $html[] = $this->renderChild($bp, $this->parent, $node);
             }
         }
 
@@ -106,9 +107,10 @@ class TreeRenderer extends Renderer
     /**
      * @param Node $node
      * @param array $path
+     * @param BpNode $parent
      * @return BaseHtmlElement[]
      */
-    public function getNodeIcons(Node $node, array $path = null)
+    public function getNodeIcons(Node $node, array $path = null, BpNode $parent = null)
     {
         $icons = [];
         if (empty($path) && $node instanceof BpNode) {
@@ -116,11 +118,11 @@ class TreeRenderer extends Renderer
         } else {
             $icons[] = $node->getIcon();
         }
-        $state = strtolower($node->getStateName());
+        $state = strtolower($node->getStateName($parent !== null ? $parent->getChildState($node) : null));
         if ($node->isHandled()) {
-            $state = $state . '-handled';
+            $state = $state . ' handled';
         }
-        $icons[] = (new StateBall($state))->addAttributes([
+        $icons[] = (new StateBall($state, StateBall::SIZE_MEDIUM))->addAttributes([
             'title' => sprintf(
                 '%s %s',
                 $state,
@@ -128,7 +130,7 @@ class TreeRenderer extends Renderer
             )
         ]);
         if ($node->isInDowntime()) {
-            $icons[] = Html::tag('i', ['class' => 'icon icon-moon']);
+            $icons[] = Html::tag('i', ['class' => 'icon icon-plug']);
         }
         if ($node->isAcknowledged()) {
             $icons[] = Html::tag('i', ['class' => 'icon icon-ok']);
@@ -136,6 +138,33 @@ class TreeRenderer extends Renderer
         return $icons;
     }
 
+    public function getOverriddenState($fakeState, Node $node)
+    {
+        $overriddenState = Html::tag('div', ['class' => 'overridden-state']);
+        $overriddenState->add(
+            (new StateBall(strtolower($node->getStateName()), StateBall::SIZE_MEDIUM))
+                ->addAttributes([
+                    'title' => sprintf(
+                        '%s',
+                        $node->getStateName()
+                    )
+                ])
+        );
+        $overriddenState->add(Html::tag('i', ['class' => 'icon icon-right-small']));
+        $overriddenState->add(
+            (new StateBall(strtolower($node->getStateName($fakeState)), StateBall::SIZE_MEDIUM))
+                ->addAttributes([
+                    'title' => sprintf(
+                        '%s',
+                        $node->getStateName($fakeState)
+                    ),
+                    'class' => 'last'
+                ])
+        );
+
+        return $overriddenState;
+    }
+
     /**
      * @param BpConfig $bp
      * @param Node $node
@@ -222,14 +251,14 @@ class TreeRenderer extends Renderer
             if ($child instanceof BpNode) {
                 $ul->add($this->renderNode($bp, $child, $path));
             } else {
-                $ul->add($this->renderChild($bp, $child, $path));
+                $ul->add($this->renderChild($bp, $node, $child, $path));
             }
         }
 
         return $li;
     }
 
-    protected function renderChild($bp, Node $node, $path = null)
+    protected function renderChild($bp, BpNode $parent, Node $node, $path = null)
     {
         $li = Html::tag('li', [
             'class'             => 'movable',
@@ -237,12 +266,16 @@ class TreeRenderer extends Renderer
             'data-node-name'    => $node->getName()
         ]);
 
-        $li->add($this->getNodeIcons($node, $path));
+        $li->add($this->getNodeIcons($node, $path, $parent));
 
         $link = $node->getLink();
         $link->getAttributes()->set('data-base-target', '_next');
         $li->add($link);
 
+        if (($overriddenState = $parent->getChildState($node)) !== $node->getState()) {
+            $li->add($this->getOverriddenState($overriddenState, $node));
+        }
+
         if (! $this->isLocked() && $node->getBpConfig()->getName() === $this->getBusinessProcess()->getName()) {
             $li->add($this->getActionIcons($bp, $node));
         }
