@@ -233,6 +233,24 @@ class LegacyConfigParser
         $bp->getBpNode($name)->setInfoUrl($url);
     }
 
+    protected function parseStateOverrides(&$line, BpConfig $bp)
+    {
+        // state_overrides <bp-node>!<child>|n-n[,n-n]!<child>|n-n[,n-n]
+        $segments = preg_split('~\s*!\s*~', substr($line, 16));
+        $node = $bp->getNode(array_shift($segments));
+        foreach ($segments as $overrideDef) {
+            list($childName, $overrides) = preg_split('~\s*\|\s*~', $overrideDef, 2);
+
+            $stateOverrides = [];
+            foreach (preg_split('~\s*,\s*~', $overrides) as $override) {
+                list($from, $to) = preg_split('~\s*-\s*~', $override, 2);
+                $stateOverrides[(int) $from] = (int) $to;
+            }
+
+            $node->setStateOverrides($stateOverrides, $childName);
+        }
+    }
+
     protected function parseExtraLine(&$line, $typeLength, BpConfig $bp)
     {
         $type = substr($line, 0, $typeLength);
@@ -251,6 +269,9 @@ class LegacyConfigParser
             case 'info_url':
                 $this->parseInfoUrl($line, $bp);
                 break;
+            case 'state_overrides':
+                $this->parseStateOverrides($line, $bp);
+                break;
             case 'template':
                 // compat, ignoring for now
                 break;
@@ -282,9 +303,9 @@ class LegacyConfigParser
             return;
         }
 
-        // Space found in the first 14 cols? Might be a line with extra information
+        // Space found in the first 16 cols? Might be a line with extra information
         $pos = strpos($line, ' ');
-        if ($pos !== false && $pos < 14) {
+        if ($pos !== false && $pos < 16) {
             if ($this->parseExtraLine($line, $pos, $bp)) {
                 return;
             }
@@ -301,7 +322,7 @@ class LegacyConfigParser
         }
 
         $op = '&';
-        if (preg_match_all('~(?<!\\\\)([\|\+&\!])~', $value, $m)) {
+        if (preg_match_all('~(?<!\\\\)([\|\+&\!\%])~', $value, $m)) {
             $op = implode('', $m[1]);
             for ($i = 1; $i < strlen($op); $i++) {
                 if ($op[$i] !== $op[$i - 1]) {
@@ -330,7 +351,7 @@ class LegacyConfigParser
 
         $cmps = preg_split('~\s*(?<!\\\\)\\' . $op . '\s*~', $value, -1, PREG_SPLIT_NO_EMPTY);
         foreach ($cmps as $val) {
-            $val = preg_replace('~(\\\\([\|\+&\!]))~', '$2', $val);
+            $val = preg_replace('~(\\\\([\|\+&\!\%]))~', '$2', $val);
             if (strpos($val, ';') !== false) {
                 if ($bp->hasNode($val)) {
                     $node->addChild($bp->getNode($val));
