@@ -158,6 +158,7 @@ class LegacyConfigRenderer
     public static function renderSingleBpNode(BpNode $node)
     {
         return static::renderExpression($node)
+            . static::renderStateOverrides($node)
             . static::renderDisplay($node)
             . static::renderInfoUrl($node);
     }
@@ -185,7 +186,7 @@ class LegacyConfigRenderer
         $op = static::renderOperator($node);
         $children = $node->getChildNames();
         $str = implode(' ' . $op . ' ', array_map(function ($val) {
-            return preg_replace('~([\|\+&\!])~', '\\\\$1', $val);
+            return preg_replace('~([\|\+&\!\%])~', '\\\\$1', $val);
         }, $children));
 
         if ((count($children) < 2) && $op !== '&') {
@@ -214,6 +215,27 @@ class LegacyConfigRenderer
         }
     }
 
+    public static function renderStateOverrides(BpNode $node)
+    {
+        $stateOverrides = '';
+        foreach ($node->getStateOverrides() as $childName => $overrideRules) {
+            $overrides = [];
+            foreach ($overrideRules as $from => $to) {
+                $overrides[] = sprintf('%d-%d', $from, $to);
+            }
+
+            if (! empty($overrides)) {
+                $stateOverrides .= '!' . $childName . '|' . join(',', $overrides);
+            }
+        }
+
+        if (! $stateOverrides) {
+            return '';
+        }
+
+        return 'state_overrides ' . $node->getName() . $stateOverrides . "\n";
+    }
+
     /**
      * @param BpNode $node
      * @return string
